==> fpds-1.3.1.tar.gz: fpds-1.3.1/tests/test_xml.py <==
import pytest
from unittest import TestCase
from xml.etree.ElementTree import ElementTree

from fpds import fpdsXML
from fpds.core.xml import fpdsElement
from tests import FULL_RESPONSE_DATA_BYTES, TRUNCATED_RESPONSE_DATA_BYTES

FPDS_REQUEST_PARAMS_DICT = {
    "LAST_MOD_DATE": "[2022/01/01, 2022/05/01]",
    "AGENCY_CODE": "7504",
}
TEST_NAMESPACE_DICT = {
    "ns0": "http://www.w3.org/2005/Atom",
    "ns1": "https://www.fpds.gov/FPDS",
}


class TestFpdsXML(TestCase):
    def setUp(self):
        self._class = fpdsXML(FULL_RESPONSE_DATA_BYTES)

    def test_invalid_content_type(self):
        with pytest.raises(TypeError):
            fpdsXML(content="a-string-not-bytes-or-tree")

    def test_convert_to_lxml_tree(self):
        content = self._class.convert_to_lxml_tree()
        self.assertIsInstance(content, ElementTree)

    def test_response_size(self):
        self.assertEqual(self._class.response_size, 10)

    def test_namespace_dict(self):
        namespace_dict = self._class.namespace_dict
        self.assertEqual(namespace_dict, TEST_NAMESPACE_DICT)

    def test_total_record_count(self):
        total = self._class.total_record_count
        self.assertEqual(total, 20)

    def test_total_record_count_truncated_response(self):
        """A truncated response won't have a `last` link tag. This test
        ensures that if the response size is less than 10 that the
        `total_record_count` property is still generated correctly.
        """
        _class = fpdsXML(TRUNCATED_RESPONSE_DATA_BYTES)
        total = _class.total_record_count
        self.assertEqual(total, 1)

    def test_pagination_links(self):
        links = self._class.pagination_links(params="some-param1: param1-value")
        self.assertEqual(len(links), 3)

    def test_get_atom_feed_entries(self):
        entries = self._class.get_atom_feed_entries()
        # all entries should be of the same type
        entry_types = set([type(entry) for entry in entries])
        self.assertEqual(len(entry_types), 1)

    def test_jsonified_entries(self):
        entries = self._class.jsonified_entries()
        self.assertEqual(len(entries), 10)


class TestFpdsElement(TestCase):
    def setUp(self):
        xml = fpdsXML(content=FULL_RESPONSE_DATA_BYTES)
        element = xml.get_atom_feed_entries()[0]
        self._class = fpdsElement(content=element)

    def test_str_magic_method(self):
        object_as_string = "<fpdsElement {http://www.w3.org/2005/Atom}entry>"
        self.assertEqual(self._class.__str__(), object_as_string)

==> fpds-1.4.1.tar.gz: fpds-1.4.1/tests/test_xml.py <==
import pytest
from unittest import TestCase
from xml.etree.ElementTree import ElementTree

from fpds import fpdsXML
from fpds.core.xml import fpdsElement
from tests import FULL_RESPONSE_DATA_BYTES, TRUNCATED_RESPONSE_DATA_BYTES

FPDS_REQUEST_PARAMS_DICT = {
    "LAST_MOD_DATE": "[2022/01/01, 2022/05/01]",
    "AGENCY_CODE": "7504",
}
TEST_NAMESPACE_DICT = {
    "ns0": "http://www.w3.org/2005/Atom",
    "ns1": "https://www.fpds.gov/FPDS",
}


class TestFpdsXML(TestCase):
    def setUp(self):
        self._class = fpdsXML(FULL_RESPONSE_DATA_BYTES)

    def test_invalid_content_type(self):
        with pytest.raises(TypeError):
            fpdsXML(content="a-string-not-bytes-or-tree")

    def test_convert_to_lxml_tree(self):
        content = self._class.convert_to_lxml_tree()
        self.assertIsInstance(content, ElementTree)

    def test_response_size(self):
        self.assertEqual(self._class.response_size, 10)

    def test_namespace_dict(self):
        namespace_dict = self._class.namespace_dict
        self.assertEqual(namespace_dict, TEST_NAMESPACE_DICT)

    def test_lower_limit(self):
        total = self._class.lower_limit
        self.assertEqual(total, 20)

    def test_lower_limit_count_truncated_response(self):
        """A truncated response won't have a `last` link tag. This test
        ensures that if the response size is less than 10 that the
        `lower_limit` property is still generated correctly.
        """
        _class = fpdsXML(TRUNCATED_RESPONSE_DATA_BYTES)
        total = _class.lower_limit
        self.assertEqual(total, 1)

    def test_pagination_links(self):
        links = self._class.pagination_links(params="some-param1: param1-value")
        self.assertEqual(len(links), 3)

    def test_get_atom_feed_entries(self):
        entries = self._class.get_atom_feed_entries()
        # all entries should be of the same type
        entry_types = set([type(entry) for entry in entries])
        self.assertEqual(len(entry_types), 1)

    def test_jsonify(self):
        entries = self._class.jsonify()
        self.assertEqual(len(entries), 10)


class TestFpdsElement(TestCase):
    def setUp(self):
        xml = fpdsXML(content=FULL_RESPONSE_DATA_BYTES)
        element = xml.get_atom_feed_entries()[0]
        self._class = fpdsElement(content=element)

    def test_str_magic_method(self):
        object_as_string = "<fpdsElement {http://www.w3.org/2005/Atom}entry>"
        self.assertEqual(self._class.__str__(), object_as_string)
